@@ -96,7 +96,7 @@ FLAGland = matrix(FALSE, ncol=ncol(mxy$x) , nrow=nrow(mxy$x))
 
  MAPXY = GLOB.XY(coastmap$POINTS$lat ,  RPMG::fmod( coastmap$POINTS$lon, 360) , PROJ )
 
- mypoly  = splancs::as.points(as.vector(mxy$x) ,as.vector(mxy$y))
+ mypoly  = cbind(as.vector(mxy$x) ,as.vector(mxy$y))
  
  if(TRUE)
    {
@@ -131,8 +131,9 @@ if(any(rads<RADmax) & rectoverlap(rx[1], ry[1], rx[2], ry[2], hx[1], hy[1], hx[2
 {
 
 
-      JJpoly = splancs::as.points(x, y)
-      INTEMP = splancs::inout(mypoly,JJpoly, bound=TRUE )
+###   
+    JJpoly = cbind(x, y)
+      INTEMP = fields::in.poly(mypoly,JJpoly, bound=TRUE )
 
      ##    points(mxy$x[INTEMP] ,mxy$y[INTEMP], pch=".", col='red') 
   FLAGland[INTEMP] = TRUE
